.. _readwrite:

**************************
Reading and writing graphs
**************************

.. toctree::
   :maxdepth: 2

   readwrite.adjlist
   readwrite.multiline_adjlist
   readwrite.edgelist
   readwrite.gexf
   readwrite.gml
   readwrite.gpickle
   readwrite.graphml
   readwrite.json_graph
   readwrite.leda
   readwrite.yaml
   readwrite.sparsegraph6
   readwrite.pajek
   readwrite.nx_shp
